@@ -7,7 +7,7 @@ use SVG::XML;
 use parent qw(SVG::Element SVG::Extension);
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '2.60';
+our $VERSION = '2.61';
 
 =pod
 
@@ -22,19 +22,22 @@ SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents
     use SVG;
 
     # create an SVG object
-    my $svg= SVG->new(width=>200,height=>200);
+    my $svg= SVG->new( width => 200, height => 200);
 
     # use explicit element constructor to generate a group element
     my $y=$svg->group(
         id    => 'group_y',
-        style => { stroke=>'red', fill=>'green' }
+        style => {
+            stroke => 'red',
+            fill   => 'green'
+        },
     );
 
     # add a circle to the group
-    $y->circle(cx=>100, cy=>100, r=>50, id=>'circle_in_group_y');
+    $y->circle( cx => 100, cy => 100, r => 50, id => 'circle_in_group_y' );
 
     # or, use the generic 'tag' method to generate a group element by name
-    my $z=$svg->tag('g',
+    my $z = $svg->tag('g',
                     id    => 'group_z',
                     style => {
                         stroke => 'rgb(100,200,50)',
@@ -43,7 +46,7 @@ SVG - Perl extension for generating Scalable Vector Graphics (SVG) documents
                 );
 
     # create and add a circle using the generic 'tag' method
-    $z->tag('circle', cx=>50, cy=>50, r=>100, id=>'circle_in_group_z');
+    $z->tag('circle', cx => 50, cy => 50, r => 100, id => 'circle_in_group_z');
 
     # create an anchor on a rectangle within a group within the group z
     my $k = $z->anchor(
@@ -83,9 +86,11 @@ L<SVG::Element>,
 L<SVG::Parser>,
 L<SVG::Extension>
 
-=head1 VERSION
+=h2 Converting to PNG and other raster image format
 
-Version 2.59
+The B<convert> command of L<http://www.imagemagick.org/> (also via L<Image::Magic> )
+
+Or L<Image::LibRSVG> can convert SVG to other format.
 
 =head1 EXAMPLES
 
@@ -122,19 +127,20 @@ object, create and access javascript, and generate SMIL animation content.
 
 Generating SVG is a simple three step process:
 
-=head2 1 The first step is to construct a new SVG object with L<"new">.
+=over 4
 
-=head2 2 The second step is to call element constructors to create SVG elements.
-Examples of element constructors are L<"circle"> and L<"path">.
+=item 1 Construct a new SVG object with L<new>.
 
-=head2 3 The third and last step is to render the SVG object into XML using the
-L<xmlify> method.
+=item 2 Call element constructors such as L<circle> and L<path> to create SVG elements.
+
+=item 3 Render the SVG object into XML using the L<xmlify> method.
+
+=back
 
 The L<xmlify> method takes a number of optional arguments that control how SVG
 renders the object into XML, and in particular determine whether a standalone
 SVG document or an inline SVG document fragment is generated:
 
-
 =head2 -standalone
 
 A complete SVG document with its own associated DTD. A namespace for the SVG
@@ -145,7 +151,6 @@ elements may be optionally specified.
 An inline SVG document fragment with no DTD that be embedded within other XML
 content. As with standalone documents, an alternate namespace may be specified.
 
-
 No XML content is generated until the third step is reached. Up until this
 point, all constructed element definitions reside in a DOM-like data structure
 from which they can be accessed and modified.
@@ -206,8 +211,6 @@ predeclared; other elements are defined as and when they are seen by Perl. Note
 that enabling '-auto' effectively disables compile-time syntax checking for
 valid method names.
 
-B<Example:>
-
     use SVG (
         -auto       => 0,
         -indent     => "  ",
@@ -228,13 +231,11 @@ Resulting XML snippet:
   <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
   <!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.0//EN" "http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
   <svg height="100%" width="100%" xmlns="http://www.w3.org/2000/svg" xmlns:svg="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
-  	<!--
-	  Generated using the Perl SVG Module V2.50
-  	by Ronan Oger
-	  Info: http://www.roitsystems.com/
-   -->
-
-
+      <!--
+        Generated using the Perl SVG Module V2.50
+          by Ronan Oger
+        Info: http://www.roitsystems.com/
+      -->
 
 =head1 METHODS
 
@@ -260,8 +261,6 @@ Creates a new SVG object. Attributes of the document SVG element be passed as
 an optional list of key value pairs. Additionally, SVG options (prefixed with
 a hyphen) may be set on a per object basis:
 
-B<Example:>
-
     my $svg1 = SVG->new;
 
     my $svg2 = SVG->new(id => 'document_element');
@@ -324,8 +323,6 @@ Generic element generator. Creates the element named $name with the attributes
 specified in %attributes. This method is the basis of most of the explicit
 element generators.
 
-B<Example:>
-
     my $tag = $svg->tag('g', transform=>'rotate(-45)');
 
 
@@ -337,8 +334,6 @@ Generate an anchor element. Anchors are put around objects to make them
 'live' (i.e. clickable). It therefore requires a drawn object or group element
 as a child.
 
-B<Example:>
-
     # generate an anchor
     $tag = $svg->anchor(
         -href=>'http://here.com/some/simpler/svg.svg'
@@ -348,8 +343,8 @@ B<Example:>
 
     # more complex anchor with both URL and target
     $tag = $svg->anchor(
-	      -href   => 'http://somewhere.org/some/other/page.html',
-	      target => 'new_window'
+          -href   => 'http://somewhere.org/some/other/page.html',
+          target => 'new_window'
     );
 
 
@@ -360,9 +355,7 @@ $tag = $svg->circle(%attributes)
 
 Draw a circle at (cx,cy) with radius r.
 
-B<Example:>
-
-    my $tag = $svg->circle(cx=>4, cy=>2, r=>1);
+    my $tag = $svg->circle(cx => 4, cy => 2, r => 1);
 
 =head2 ellipse
 
@@ -370,8 +363,6 @@ $tag = $svg->ellipse(%attributes)
 
 Draw an ellipse at (cx,cy) with radii rx,ry.
 
-B<Example:>
-
     my $tag = $svg->ellipse(
         cx=>10, cy=>10,
         rx=>5, ry=>7,
@@ -393,8 +384,6 @@ $tag = $svg->rectangle(%attributes)
 Draw a rectangle at (x,y) with width 'width' and height 'height' and side radii
 'rx' and 'ry'.
 
-B<Example:>
-
     $tag = $svg->rectangle(
         x=>10, y=>20,
         width=>4, height=>5,
@@ -409,13 +398,11 @@ B<Example:>
 Draw an image at (x,y) with width 'width' and height 'height' linked to image
 resource '-href'. See also L<"use">.
 
-B<Example:>
-
     $tag = $svg->image(
-        x=>100, y=>100,
-        width=>300, height=>200,
-        '-href'=>"image.png", #may also embed SVG, e.g. "image.svg"
-        id=>'image_1'
+        x => 100, y => 100,
+        width => 300, height => 200,
+        '-href' => "image.png", #may also embed SVG, e.g. "image.svg"
+        id => 'image_1'
     );
 
 B<Output:>
@@ -429,8 +416,6 @@ $tag = $svg->use(%attributes)
 Retrieve the content from an entity within an SVG document and apply it at
 (x,y) with width 'width' and height 'height' linked to image resource '-href'.
 
-B<Example:>
-
     $tag = $svg->use(
         x=>100, y=>100,
         width=>300, height=>200,
@@ -450,30 +435,28 @@ single element within an external SVG file.
 $tag = $svg->polygon(%attributes)
 
 Draw an n-sided polygon with vertices at points defined by a string of the form
-'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<"get_path"> method is provided as a
+'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<get_path> method is provided as a
 convenience to generate a suitable string from coordinate data.
 
-B<Example:>
-
     # a five-sided polygon
-    my $xv = [0,2,4,5,1];
-    my $yv = [0,0,2,7,5];
+    my $xv = [0, 2, 4, 5, 1];
+    my $yv = [0, 0, 2, 7, 5];
 
-    $points = $a->get_path(
-        x=>$xv, y=>$yv,
-        -type=>'polygon'
+    my $points = $svg->get_path(
+        x     =>  $xv,
+        y     =>  $yv,
+        -type =>'polygon'
     );
 
-    $c = $a->polygon(
+    my $poly = $svg->polygon(
         %$points,
-        id=>'pgon1',
-        style=>\%polygon_style
+        id    => 'pgon1',
+        style => \%polygon_style
     );
 
 SEE ALSO:
 
-L<"polyline">, L<"path">, L<"get_path">.
-
+L<polyline>, L<path>, L<get_path>.
 
 =head2 polyline
 
@@ -483,24 +466,23 @@ Draw an n-point polyline with points defined by a string of the form
 'x1,y1,x2,y2,x3,y3,... xy,yn'. The L<"get_path"> method is provided as a
 convenience to generate a suitable string from coordinate data.
 
-B<Example:>
-
     # a 10-pointsaw-tooth pattern
-    my $xv = [0,1,2,3,4,5,6,7,8,9];
-    my $yv = [0,1,0,1,0,1,0,1,0,1];
+    my $xv = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9];
+    my $yv = [0, 1, 0, 1, 0, 1, 0, 1, 0, 1];
 
-    $points = $a->get_path(
-        x=>$xv, y=>$yv,
-        -type=>'polyline',
-        -closed=>'true' #specify that the polyline is closed.
+    my $points = $svg->get_path(
+        x       => $xv,
+        y       => $yv,
+        -type   => 'polyline',
+        -closed => 'true' #specify that the polyline is closed.
     );
 
-    my $tag = $a->polyline (
+    my $tag = $svg->polyline (
         %$points,
-        id=>'pline_1',
-        style=>{
+        id    =>'pline_1',
+        style => {
             'fill-opacity' => 0,
-            'stroke' => 'rgb(250,123,23)'
+            'stroke'       => 'rgb(250,123,23)'
         }
     );
 
@@ -510,12 +492,12 @@ $tag = $svg->line(%attributes)
 
 Draw a straight line between two points (x1,y1) and (x2,y2).
 
-B<Example:>
-
     my $tag = $svg->line(
-        id=>'l1',
-        x1=>0, y1=>10,
-        x2=>10, y2=>0
+        id => 'l1',
+        x1 =>  0,
+        y1 => 10,
+        x2 => 10,
+        y2 =>  0,
     );
 
 To draw multiple connected lines, use L<"polyline">.
@@ -529,30 +511,38 @@ $text_span = $text_path->text(-type=>'span')->cdata('A');
 $text_span = $text_path->text(-type=>'span')->cdata('B');
 $text_span = $text_path->text(-type=>'span')->cdata('C');
 
-
-define the container for a text string to be drawn in the image.
+Define the container for a text string to be drawn in the image.
 
 B<Input:>
+
     -type     = path type (path | polyline | polygon)
     -type     = text element type  (path | span | normal [default])
 
-B<Example:>
-
     my $text1 = $svg->text(
-        id=>'l1', x=>10, y=>10
+        id => 'l1',
+        x  => 10,
+        y  => 10
     )->cdata('hello, world');
 
     my $text2 = $svg->text(
-        id=>'l1', x=>10, y=>10, -cdata=>'hello, world');
+        id     => 'l1',
+        x      => 10,
+        y      => 10,
+        -cdata => 'hello, world',
+    );
 
     my $text = $svg->text(
-        id=>'tp', x=>10, y=>10 -type=>path)
-        ->text(id=>'ts' -type=>'span')
-        ->cdata('hello, world');
+        id    => 'tp',
+        x     => 10,
+        y     => 10,
+        -type => path,
+    )
+      ->text(id=>'ts' -type=>'span')
+      ->cdata('hello, world');
 
 SEE ALSO:
 
-    L<"desc">, L<"cdata">.
+L<desc>, L<cdata>.
 
 =head2 title
 
@@ -560,8 +550,6 @@ $tag = $svg->title(%attributes)
 
 Generate the title of the image.
 
-B<Example:>
-
     my $tag = $svg->title(id=>'document-title')->cdata('This is the title');
 
 =head2 desc
@@ -570,8 +558,6 @@ $tag = $svg->desc(%attributes)
 
 Generate the description of the image.
 
-B<Example:>
-
     my $tag = $svg->desc(id=>'document-desc')->cdata('This is a description');
 
 =head2 comment
@@ -580,8 +566,6 @@ $tag = $svg->comment(@comments)
 
 Generate the description of the image.
 
-B<Example:>
-
     my $tag = $svg->comment('comment 1','comment 2','comment 3');
 
 =head2 pi (Processing Instruction)
@@ -590,8 +574,6 @@ $tag = $svg->pi(@pi)
 
 Generate a set of processing instructions
 
-B<Example:>
-
     my $tag = $svg->pi('instruction one','instruction two','instruction three');
 
     returns:
@@ -606,24 +588,22 @@ $tag = $svg->script(%attributes)
 Generate a script container for dynamic (client-side) scripting using
 ECMAscript, Javascript or other compatible scripting language.
 
-B<Example:>
-
     my $tag = $svg->script(-type=>"text/ecmascript");
     #or my $tag = $svg->script();
     #note that type ecmascript is not Mozilla compliant
 
     # populate the script tag with cdata
     # be careful to manage the javascript line ends.
-    # qq|text| or qq§text§ where text is the script
-    # works well for this.
-    #make sure to use the CAPITAL CDATA to poulate the script.
-    $tag->CDATA(qq|function d(){
+    # Use qq{text} or q{text} as appropriate.
+    # make sure to use the CAPITAL CDATA to poulate the script.
+    $tag->CDATA(qq{
+        function d() {
         //simple display function
-        for(cnt = 0; cnt < d.length; cnt++)
+          for(cnt = 0; cnt < d.length; cnt++)
             document.write(d[cnt]);//end for loop
         document.write("<BR>");//write a line break
-      }|
-    );
+        }
+    });
 
 =head2 path
 
@@ -632,13 +612,11 @@ $tag = $svg->path(%attributes)
 Draw a path element. The path vertices may be imputed as a parameter or
 calculated usingthe L<"get_path"> method.
 
-B<Example:>
-
     # a 10-pointsaw-tooth pattern drawn with a path definition
     my $xv = [0,1,2,3,4,5,6,7,8,9];
     my $yv = [0,1,0,1,0,1,0,1,0,1];
 
-    $points = $a->get_path(
+    $points = $svg->get_path(
         x => $xv,
         y => $yv,
         -type   => 'path',
@@ -656,9 +634,7 @@ B<Example:>
     );
 
 
-SEE ALSO:
-
-L<"get_path">.
+SEE ALSO: L<get_path>.
 
 =head2 get_path
 
@@ -680,8 +656,6 @@ B<Output:> a hash reference consisting of the following key-value pair:
     -relative = 1 (define relative position rather than absolute position)
     -closed   = 1 (close the curve - path and polygon only)
 
-B<Example:>
-
     #generate an open path definition for a path.
     my ($points,$p);
     $points = $svg->get_path(x=&gt\@x,y=&gt\@y,-relative=&gt1,-type=&gt'path');
@@ -752,8 +726,6 @@ $tag = $svg->group(%attributes)
 Define a group of objects with common properties. groups can have style,
 animation, filters, transformations, and mouse actions assigned to them.
 
-B<Example:>
-
     $tag = $svg->group(
         id        => 'xvs000248',
         style     => {
@@ -769,7 +741,6 @@ B<Example:>
 $tag = $svg->defs(%attributes)
 
 define a definition segment. A Defs requires children when defined using SVG.pm
-B<Example:>
 
     $tag = $svg->defs(id  =>  'def_con_one',);
 
@@ -782,6 +753,30 @@ Sets/Adds style-definition for the following objects being created.
 Style definitions apply to an object and all its children for all properties for
 which the value of the property is not redefined by the child.
 
+  $tag = $SVG->style(%attributes)
+
+Generate a style container for inline or xlink:href based styling instructions
+
+    my $tag = $SVG->style(type=>"text/css");
+
+    # Populate the style tag with cdata.
+    # Be careful to manage the line ends.
+    # qq|text| or qq§text§, where text is the script
+    # work well for this.
+
+    $tag1->CDATA(qq{
+        rect     fill:red;stroke:green;
+        circle   fill:red;stroke:orange;
+        ellipse  fill:none;stroke:yellow;
+        text     fill:black;stroke:none;
+    });
+    
+    # Create a external CSS stylesheet reference
+    my $tag2 = $SVG->style(type=>"text/css", -href="/resources/example.css");
+
+=pod
+
+
 =head2 mouseaction
 
 $svg->mouseaction(%attributes)
@@ -811,8 +806,6 @@ meant to be an empty tag, SVG.pm will not complain, but the rendering agent will
 fail. In the SVG DTD, cdata is generally only meant for adding text or script
 content.
 
-B<Example:>
-
     $svg->text(
         style => {
             'font'      => 'Arial',
@@ -822,14 +815,13 @@ B<Example:>
     my $text = $svg->text(style=>{'font'=>'Arial','font-size'=>20});
     $text->cdata('SVG.pm is a perl module on CPAN!');
 
-
 B<Result:>
 
-    E<lt>text style="font: Arial; font-size: 20" E<gt>SVG.pm is a perl module on CPAN!E<lt>/text E<gt>
+    <text style="font: Arial; font-size: 20">SVG.pm is a perl module on CPAN!</text>
 
 SEE ALSO:
 
-  L<"CDATA"> L<"desc">, L<"title">, L<"text">, L<"script">.
+L<CDATA>, L<desc>, L<title>, L<text>, L<script>.
 
 =head2 cdata_noxmlesc
 
@@ -849,9 +841,7 @@ meant to be an empty tag, SVG.pm will not complain, but the rendering agent will
 fail. In the SVG DTD, cdata is generally only meant for adding text or script
 content.
 
-B<Example:>
-
-      my $text = qq§
+      my $text = qq{
         var SVGDoc;
         var groups = new Array();
         var last_group;
@@ -869,7 +859,7 @@ B<Example:>
             append_group(1, 4, 6); // group 0
             append_group(5, 4, 3); // group 1
             append_group(2, 3);    // group 2
-        }§;
+        }};
         $svg->script()->CDATA($text);
 
 
@@ -897,9 +887,7 @@ B<Result:>
         }
         ]]E<gt>
 
-SEE ALSO:
-
-  L<"cdata">, L<"script">.
+SEE ALSO: L<cdata>, L<script>.
 
 =head2 xmlescp and xmlescape
 
@@ -926,8 +914,6 @@ $tag = $svg->filter(%attributes)
 
 Generate a filter. Filter elements contain L<"fe"> filter sub-elements.
 
-B<Example:>
-
     my $filter = $svg->filter(
         filterUnits=>"objectBoundingBox",
         x=>"-10%",
@@ -939,9 +925,7 @@ B<Example:>
 
     $filter->fe();
 
-SEE ALSO:
-
-L<"fe">.
+SEE ALSO: L<fe>.
 
 =head2 fe
 
@@ -949,8 +933,6 @@ $tag = $svg->fe(-type=>'type', %attributes)
 
 Generate a filter sub-element. Must be a child of a L<"filter"> element.
 
-B<Example:>
-
     my $fe = $svg->fe(
         -type     => 'DiffuseLighting'  # required - element name omiting 'fe'
         id        => 'filter_1',
@@ -1014,9 +996,7 @@ Note that the following filter elements are currently supported:
 =head2 * feTurbulence
 
 
-SEE ALSO:
-
-L<"filter">.
+SEE ALSO: L<filter>.
 
 =head2 pattern
 
@@ -1024,8 +1004,6 @@ $tag = $svg->pattern(%attributes)
 
 Define a pattern for later reference by url.
 
-B<Example:>
-
     my $pattern = $svg->pattern(
         id     => "Argyle_1",
         width  => "50",
@@ -1041,8 +1019,6 @@ $tag = $svg->set(%attributes)
 Set a definition for an SVG object in one section, to be referenced in other
 sections as needed.
 
-B<Example:>
-
     my $set = $svg->set(
         id     => "Argyle_1",
         width  => "50",
@@ -1057,8 +1033,6 @@ $tag = $svg->stop(%attributes)
 
 Define a stop boundary for L<"gradient">
 
-B<Example:>
-
    my $pattern = $svg->stop(
        id     => "Argyle_1",
        width  => "50",
@@ -1071,8 +1045,6 @@ $tag = $svg->gradient(%attributes)
 
 Define a color gradient. Can be of type B<linear> or B<radial>
 
-B<Example:>
-
     my $gradient = $svg->gradient(
         -type => "linear",
         id    => "gradient_1"
@@ -1280,8 +1252,6 @@ Creates a new SVG object. Attributes of the document SVG element be passed as
 an optional list of key value pairs. Additionally, SVG options (prefixed with
 a hyphen) may be set on a per object basis:
 
-B<Example:>
-
     my $svg1 = SVG->new;
 
     my $svg2 = SVG->new(id => 'document_element');
